/*******************************************************************************
* Copyright (c) 2016 Red Hat, Inc. All rights reserved.
* The contents of this file are made available under the terms
* of the GNU Lesser General Public License (LGPL) Version 2.1 that
* accompanies this distribution (lgpl-v21.txt).  The LGPL is also
* available at http://www.gnu.org/licenses/lgpl.html.  If the version
* of the LGPL at http://www.gnu.org is different to the version of
* the LGPL accompanying this distribution and there is any conflict
* between the two license versions, the terms of the LGPL accompanying
* this distribution shall govern.
*
* Contributors:
*     Red Hat, Inc
*******************************************************************************/

#ifndef INC_webkitgtk_custom_H
#define INC_webkitgtk_custom_H

/* Manually written code */
/** Dynamic type definitions */
typedef jlong 	dyn_WebKitWebView;
typedef gpointer 	dyn_WebKitJavascriptResult;
typedef gpointer 	dyn_JSContextRef;
typedef gpointer 	dyn_JSGlobalContextRef;
typedef gpointer    dyn_JSStringRef;
typedef const void *dyn_JSValueRef;

#endif /*INC_webkit_custom_H*/

